@@ -8,12 +8,13 @@ command2module = {
     "run": "dptools.lmp.simulations",
     #"sample": "dptools.sample",
     "convert": "dptools.utils",
-    #"set": "dptools.?", set .env: graph, typemap
-    #"get": "dptools.?", get params, ?
+    "set": "dptools.env",
+    "get": "dptools.lmp.parameters",
     #"info": "dptools.?", show env stuff
 }
 
 class BaseCLI:
+    help_info = ""
     def __init__(self, parser):
         self.parser = parser
 
